CMSInsertAction class

Inheritance

Constructors

CMSInsertAction({required String id, required ID cubitID, required ID stateID, required ID variableID, String type = 'cms_insert', String group = ActionGroups.cms, required String table, String? select, required int? limit, required int? offset, required String? orderBy, required bool isCount, required List<SupasetFilterEntity> filters})
const

Properties

cubitID → ID
finalinherited
filters → List<SupasetFilterEntity>
finalinherited
group → ID
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → ID
finalinherited
isCount → bool
finalinherited
limit → int?
finalinherited
offset → int?
finalinherited
orderBy → String?
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
select → String?
finalinherited
stateID → ID
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
table → ID
finalinherited
type → ID
finalinherited
variableID → ID
finalinherited

Methods

copyWith({String? id, String? type, String? group, ID? cubitID, ID? stateID, ID? variableID, String? table, String? select, int? limit, int? offset, String? orderBy, bool? isCount, List<SupasetFilterEntity>? filters}) → ActionEntity
getWarningAndErrors(ID nodeID, BuildContext context) → EditorWarningAndErrorsEntity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performInsert(SupabaseClient client, Map<String, dynamic> data) → PostgrestFilterBuilder
toJson() → Map<String, dynamic>
inherited
toString() → ID
A string representation of this object.
inherited
toStringGroup() → ID
inherited
toStringName() → ID
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited