ShowDialogAction class

Inheritance

Constructors

ShowDialogAction({required String id, required List<ComponentParameterField> passingParameterValues, String type = 'show_dialog', required ID componentID})
const

Properties

componentID → String
final
group → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
passingParameterValues → List<ComponentParameterField>
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → String
finalinherited

Methods

copyWith({ID? componentID, List<ComponentParameterField>? passingParameterValues}) → ShowDialogAction
getWarningAndErrors(ID nodeID, BuildContext context) → EditorWarningAndErrorsEntity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited
toStringGroup() → String
inherited
toStringName() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ShowDialogAction
override