SupabaseAction class abstract

Inheritance
Implementers

Constructors

SupabaseAction({required String id, required ID requestID, required List<SupabaseActionFieldEntity> filters, required List<ActionEntity> actionsIfSuccess, required List<ActionEntity> actionsIfError, String type = '', String group = ActionGroups.supabase})
const

Properties

actionsIfError → List<ActionEntity>
final
actionsIfSuccess → List<ActionEntity>
final
filters → List<SupabaseActionFieldEntity>
final
group → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
requestID → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → String
finalinherited

Methods

getWarningAndErrors(ID nodeID, BuildContext context) → EditorWarningAndErrorsEntity
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
toStringGroup() → String
override
toStringName() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

types → List<String>
no setter

Static Methods

fromJson(Map<String, dynamic> json, ActionMapper mapper) → APIRequestAction
override