AssingVariableFromStaticDoubleValue class

Inheritance

Constructors

AssingVariableFromStaticDoubleValue({required String id, String type = 'assign_variable', required ID? cubitID, required ID? stateID, required ID? variableID, AssignVariableActionTypes assingFromType = AssignVariableActionTypes.valueFromStaticDouble, String? jsonKey, required double value, int? targetIndex})
const

Properties

assingFromType → AssignVariableActionTypes
finalinherited
cubitID → ID?
finalinherited
group → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
jsonKey → ID?
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateID → ID?
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
targetIndex → int?
finalinherited
type → String
finalinherited
value → double
final
variableID → ID?
finalinherited

Methods

copyWith({ID? cubitID, ID? stateID, ID? variableID, String? jsonKey, double? value, int? targetIndex}) → AssingVariableFromStaticDoubleValue
getWarningAndErrors(ID nodeID, BuildContext context) → EditorWarningAndErrorsEntity
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited
toStringGroup() → String
inherited
toStringName() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → AssingVariableFromStaticDoubleValue
override