CubitEntity class

Constructors

CubitEntity({required ID id, required String name, required ID initialState, required Map<ID, CubitStateEntity> states, required Map<ID, WorkflowEntity> workflows, ID? currentState, List<CubitStateEntity> stateHistory = const []})
const

Properties

currentState → ID?
final
hashCode → int
The hash code for this object.
no setterinherited
id → ID
final
initialState → ID
final
name → ID
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → CubitStateEntity
no setter
stateHistory → List<CubitStateEntity>
final
states → Map<ID, CubitStateEntity>
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
workflows → Map<ID, WorkflowEntity>
final

Methods

copyWith({ID? id, String? name, ID? initialState, Map<ID, CubitStateEntity>? states, Map<ID, WorkflowEntity>? workflows, ID? currentState, List<CubitStateEntity>? stateHistory}) → CubitEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → ID
A string representation of this object.
updateState(CubitStateEntity state) → CubitEntity

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → CubitEntity