PageEntity class

Entity for a page inside a project. Uses a Mapper to serialize/deserialize.

Inheritance
Implementers

Constructors

PageEntity({required PageID id, required BranchID branchID, required String name, required PageID? stabilID, PageTypes type = PageTypes.page, TeamID? sharedTeamID, ID? variantID})
const

Properties

branchID BranchID
final
hashCode int
The hash code for this object.
no setterinherited
id BranchID
final
name BranchID
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedTeamID TeamID?
final
stabilID TeamID?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type PageTypes
final
variantID TeamID?
final

Methods

copyWith({String? id, String? branchID, String? name, String? stabilID, String? sharedTeamID, ID? variantID}) PageEntity
getWarningAndErrors(ID nodeID, BuildContext context) EditorWarningAndErrorsEntity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() BranchID
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited