ParameterVariable class

Inheritance

Constructors

ParameterVariable({required ID id, required String name, ParameterTypes type = ParameterTypes.variable, required Variable variable})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → ID
finalinherited
name → ID
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → ParameterTypes
finalinherited
variable → Variable
final

Methods

copyWith({ID? id, String? name, Variable? variable}) → ParameterVariable
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → ID
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ParameterVariable
override
fromJsonList(List jsonList) → List<ParameterVariable>
override