PassingParameter class abstract

Implementers

Constructors

PassingParameter({required ID parameterID, required PassingParameterTypes type})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameterID → ID
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → PassingParameterTypes
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → ID
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → PassingParameter
fromJsonList(List jsonList) → List<PassingParameter>