GoogleMapsControllerVariable class
Properties
-
cameraPosition
→ CameraPosition?
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ ID
-
finalinherited
-
isNullable
→ bool
-
finalinherited
-
mapController
→ GoogleMapController?
-
final
-
name
→ ID
-
finalinherited
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
-
type
→ VariableTypes
-
finalinherited
Methods
-
copyWith({ID? id, String? name, VariableTypes? type, bool? isGlobal, bool? isSavedLocally, bool? isNullable, GoogleMapController? mapController, CameraPosition? cameraPosition})
→ Variable
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setData(Variable variable, dynamic value, {String? modelID, String? enumValue})
→ Variable
-
inherited
-
toJson()
→ Map<String, dynamic>
-
inherited
-
toString()
→ ID
-
A string representation of this object.
inherited