DefaultAttributesAdapter class abstract

Implementers

Constructors

DefaultAttributesAdapter()
const

Properties

get → Map<String, dynamic>
Get the default attributes for a widget
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiredAttributes(String nodeType) → List<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited