FBorder class

FBorder is a set of functions to use Border in widgets in Teta

Annotations

Constructors

FBorder({required FFill fill, required FMargins width, required FBorderStyle style})
Constructor
const

Properties

fill → FFill
The fill of Border. It must be solid only
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
style → FBorderStyle
The style of Border
final
width → FMargins
The width of Border
final

Methods

copyWith({FFill? fill, FMargins? width, FBorderStyle? style}) → FBorder
get(BuildContext context, {required int loop}) → Border
Get Border from actual values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert FBorder to Json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> doc) → FBorder
Instantiate FBorder from Json