FBorderRadius class

FBorderRadius is a set of functions to use BorderRadius in widgets in Teta

Annotations

Constructors

FBorderRadius({required List<double> radiusMobile, List<double>? radiusTablet, List<double>? radiusDesktop})
Constructor
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
radiusDesktop → List<double>?
final
radiusMobile → List<double>
The value of FBorderRadius, used to display BorderRadius
final
radiusTablet → List<double>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({List<double>? radiusMobile, List<double>? radiusTablet, List<double>? radiusDesktop}) → FBorderRadius
get(BuildContext context) → BorderRadius
Convert radius to BorderRadius
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert FBorderRadius to Json
toString() → String
A string representation of this object.
inherited
update({required BuildContext context, required List<double> value, required DeviceType deviceType}) → Map<String, dynamic>
Change the value of value (List

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) → FBorderRadius
Instantiate FBorderRadius from Json