ConditionParameterComponentParameter class

Inheritance

Constructors

ConditionParameterComponentParameter({required ID? parameterID, FormatOptionsHelper formatOptionsHelper = const FormatOptionsHelper(options: []), required int? listIndex})
const

Properties

formatOptionsHelper → FormatOptionsHelper
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
listIndex → int?
final
parameterID → ID?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → ConditionParameterTypes
finalinherited

Methods

copyWith({ID? parameterID, ID? stateID, ID? variableID, int? listIndex, FormatOptionsHelper? formatOptionsHelper}) → ConditionParameterComponentParameter
getValue(BuildContext context, int loop) → dynamic
override
getValueModified(dynamic v, BuildContext context, int loop) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ConditionParameterComponentParameter
override