FCondition class

Implementers
Annotations

Constructors

FCondition({FConditionType conditionType = const FConditionType(), ConditionParameter firstParameter = const ConditionParameterText(value: ''), ConditionParameter secondParameter = const ConditionParameterText(value: ''), List<SubCondition> subConditions = const []})
const

Properties

conditionType → FConditionType
final
firstParameter → ConditionParameter
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondParameter → ConditionParameter
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subConditions → List<SubCondition>
final

Methods

and(bool firstCondition, bool secondCondition) → bool
copyWith({ConditionParameter? firstParameter, ConditionParameter? secondParameter, FConditionType? conditionType, List<SubCondition>? subConditions}) → FCondition
getValue<T>(BuildContext context, T ifTrue(), T ifFalse(), int loop, dynamic inputValue) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
or(bool firstCondition, bool secondCondition) → bool
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → FCondition