DynamicDropdownSource class

Inheritance

Constructors

DynamicDropdownSource({required VariableTypeInput list, required VariableTypeInput label, required VariableTypeInput value, DropdownSourceTypes type = DropdownSourceTypes.dynamic})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → VariableTypeInput
final
list → VariableTypeInput
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → DropdownSourceTypes
finalinherited
value → VariableTypeInput
final

Methods

copyWith({VariableTypeInput? list, VariableTypeInput? label, VariableTypeInput? value}) → DynamicDropdownSource
getWarningAndErrors(ID nodeID, BuildContext context) → EditorWarningAndErrorsEntity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → DynamicDropdownSource
override