FHoverEffect class

Constructors

FHoverEffect({double opacity = 1, double scale = 1, double rotate = 0, Offset offset = Offset.zero, FFill? fill, FShadow? shadow, FCurve curve = const FCurve(curve: Curves.easeInOut)})
const

Properties

curve → FCurve
final
fill → FFill?
final
hashCode → int
The hash code for this object.
no setterinherited
offset → Offset
final
opacity → double
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rotate → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final
shadow → FShadow?
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({double? opacity, double? scale, double? rotate, Offset? offset, FFill? fill, FShadow? shadow, FCurve? curve}) → FHoverEffect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → FHoverEffect