FFill class

Class to use solid colors, gradients, images inside Teta

Inheritance

Constructors

FFill({FFillType type = FFillType.solid, Alignment? begin, Alignment? end, Alignment? center, double? radius, FBoxFit? boxFit, String? paletteStyle, List<FFillElement> levels = const [FFillElement(color: '000000', stop: 0)], ID? variableID, JsonGetAttribute? jsonGetAttribute})
Constructor
const

Properties

begin → Alignment?
final
boxFit → FBoxFit?
final
center → Alignment?
final
end → Alignment?
final
hashCode → int
The hash code for this object.
no setterinherited
jsonGetAttribute → JsonGetAttribute?
final
levels → List<FFillElement>
final
paletteStyle → String?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
radius → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → FFillType
final
variableID → String?
final

Methods

alignToCode(Alignment? value) → String
alignToJson(Alignment? value) → dynamic
copyWith({List<FFillElement>? levels, FFillType? type, Alignment? begin, Alignment? end, Alignment? center, double? radius, FBoxFit? boxFit, dynamic paletteStyle, ID? variableID, JsonGetAttribute? jsonGetAttribute}) → FFill
getColor(BuildContext context, int loop) → Color
getGradient() → Gradient?
getHexColor(Map<String, ColorStyleEntity> styles, ThemeMode themeMode) → String
Get Hex String value. Includes PaletteStyle checks. String is uppercased.
getWarningAndErrors(ID nodeID, BuildContext context) → EditorWarningAndErrorsEntity
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ready(FFillType type) → FFill
Set of FFill ready to be used
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
typeToCode(FFillType? type) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alignFromJson(Map<String, dynamic> json, String key) → Alignment?
fromJson(Map<String, dynamic> json) → FFill
listFromJson(List json) → List<FFill>