FFillElement class

Make easier including colors, gradients and images in Teta

Annotations

Constructors

FFillElement({required String color, required double stop, double opacity = 1})
Constructor
const

Properties

color → String
Hex String (6 chars)
final
hashCode → int
The hash code for this object.
no setterinherited
opacity → double
double value for opacity
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stop → double
int value for gradients
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? color, double? opacity, double? stop}) → FFillElement
getLevelColor() → Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson({required Map<String, dynamic> json}) → FFillElement