FTextAlign class

Inheritance
Annotations

Constructors

FTextAlign({TextAlign value = TextAlign.left})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value → TextAlign
no setterinherited
valueString → String
no setterinherited

Methods

copyWith({TextAlign? value}) → Feature<TextAlign>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() → String
inherited
toJson() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String json) → FTextAlign