FTextStyle class

Constructors

FTextStyle({FFill fill = const FFill(type: FFillType.solid, levels: [FFillElement(color: 'ffffff', stop: 0)]), FFontSize fontSize = const FFontSize(), String fontFamily = 'Poppins', FFontWeight fontWeight = const FFontWeight(), FTextDecoration textDecoration = const FTextDecoration(), FTextAlign textAlign = const FTextAlign(), FFontStyle fontStyle = const FFontStyle(), String? textStyleModel, FTextDirection textDirection = const FTextDirection(), FGeneralTypeInput letterSpacing = const StaticTypeInput(value: '', type: FGeneralTypeEnum.text), FGeneralTypeInput lineSpacing = const StaticTypeInput(value: '', type: FGeneralTypeEnum.text)})
Set of funcs to use TextStyle in Teta's widgets
const

Properties

fill → FFill
final
fontFamily → String
final
fontSize → FFontSize
final
fontStyle → FFontStyle
final
fontWeight → FFontWeight
final
hashCode → int
The hash code for this object.
no setterinherited
letterSpacing → FGeneralTypeInput
final
lineSpacing → FGeneralTypeInput
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
textAlign → FTextAlign
final
textDecoration → FTextDecoration
final
textDirection → FTextDirection
final
textStyleModel → String?
final

Methods

copyWith({FFill? fill, FFontSize? fontSize, String? fontFamily, FFontWeight? fontWeight, FTextDecoration? textDecoration, FTextAlign? textAlign, FFontStyle? fontStyle, FTextDirection? textDirection, String? textStyleModel, FGeneralTypeInput? letterSpacing, FGeneralTypeInput? lineSpacing}) → FTextStyle
Returns style (TextStyle) only
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setModelNull() → FTextStyle
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> doc) → FTextStyle