RectProperties class

Constructors

RectProperties({required ResponsiveRect rect, bool flipRectWhileResizing = false, bool flipChild = false, bool constraintsEnabled = false, bool resizable = false, bool movable = false, bool hideHandlesWhenNotResizable = false, ResponsiveAlignment verticalAlign = ResponsiveAlignment.start, ResponsiveAlignment horizontalAlign = ResponsiveAlignment.start})
const

Properties

constraintsEnabled → bool
final
flipChild → bool
final
flipRectWhileResizing → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hideHandlesWhenNotResizable → bool
final
horizontalAlign → ResponsiveAlignment
final
movable → bool
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rect → ResponsiveRect
final
resizable → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
verticalAlign → ResponsiveAlignment
final

Methods

copyWith({ResponsiveRect? rect, bool? flipRectWhileResizing, bool? flipChild, bool? constraintsEnabled, bool? resizable, bool? movable, bool? hideHandlesWhenNotResizable, ResponsiveAlignment? verticalAlign, ResponsiveAlignment? horizontalAlign}) → RectProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → RectProperties