WorkflowEntityOverride class

Constructors

WorkflowEntityOverride({required ID id, required ID nodeID, required WorkflowEntity workflow})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → ID
final
nodeID → ID
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
workflow → WorkflowEntity
final

Methods

copyWith({ID? id, ID? nodeID, WorkflowEntity? workflow}) → WorkflowEntityOverride
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → ID
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json, ActionMapper actionMapper) → WorkflowEntityOverride
fromJsonList(List json, ActionMapper actionMapper) → List<WorkflowEntityOverride>