AppState class

PageState is the state of the tree

Constructors

AppState({required bool forPlay, Map<ID, CubitEntity Function()> cubits = const {}, Map<ID, CubitEntity> instantiatedCubits = const {}, Map<ID, MapPagesEntry> inEditorPages = const {}, Map<ID, Widget Function()> forPlayPages = const {}, Map<ID, String Function()> forPlayComponentsIDToName = const {}})
const

Properties

allCubits → List<CubitEntity>
no setter
cubits → Map<ID, CubitEntity Function()>
final
forPlay → bool
final
forPlayComponentsIDToName → Map<ID, String Function()>
final
forPlayPages → Map<ID, Widget Function()>
final
hashCode → int
The hash code for this object.
no setterinherited
inEditorPages → Map<ID, MapPagesEntry>
final
instantiatedCubits → Map<ID, CubitEntity>
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
workflows → List<WorkflowEntity>
final

Methods

addCubit(CubitEntity cubit) → AppState
copyWith({bool? forPlay, Map<ID, CubitEntity Function()>? cubits, Map<ID, CubitEntity>? instantiatedCubits, Map<ID, MapPagesEntry>? inEditorPages, Map<ID, Widget Function()>? forPlayPages, Map<ID, String Function()>? forPlayComponentsIDToName}) → AppState
getCubitByID(ID id) → CubitEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited