AppScreenSizeState class

PageState is the state of the tree

Constructors

AppScreenSizeState({required Size screenSize})
const

Properties

deviceInfo → DeviceInfo
Get the device info based on the screen size
no setter
deviceType → DeviceType
Get the device type (phone, tablet, laptop, desktop) based on the screen size
no setter
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenSize → Size
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({Size? screenSize}) → AppScreenSizeState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited