AppStylesState class

PageState is the state of the tree

Constructors

AppStylesState({required Map<String, ColorStyleEntity> colorStyles, required Map<String, TextStyleEntity> textStyles})
colorStyles is the list of color styles textStyles is the list of text styles
const

Properties

colorStyles → Map<String, ColorStyleEntity>
The color styles
final
colorStylesList → List<ColorStyleEntity>
no setter
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
textStyles → Map<String, TextStyleEntity>
The text styles
final
textStylesList → List<TextStyleEntity>
no setter

Methods

copyWith({Map<String, ColorStyleEntity>? colorStyles, Map<String, TextStyleEntity>? textStyles}) → AppStylesState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkEquality(dynamic a, dynamic b) → bool