WorkflowExecuter class

Constructors

WorkflowExecuter({required NodeID nodeID, required String nodeName, required List<Workflow> workflows})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodeID → NodeID
final
nodeName → NodeID
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
workflows → List<Workflow>
final

Methods

doesWorkflowExist(Trigger trigger) → bool
execute(Trigger trigger, dynamic val) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → NodeID
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited