OpenWContainer class

Returns a Container widget It requires a width and height for the width and height properties It takes a child of type CNode as child It requires a margins and paddings for the margin and padding properties It requires a fill for the decoration property It requires a borderRadius for the decoration property It requires a borders for the decoration property It requires a shadows for the decoration property

Inheritance

Constructors

OpenWContainer({Key? key, required DSWidgetState nodeState, required CNode? child, required FSize width, required FSize height, required FMargins paddings, required FFill fill, required FBorderRadius borderRadius, required FBorder borders, required FShadow shadows})
const

Properties

borderRadius → FBorderRadius
final
borders → FBorder
final
child → CNode?
final
fill → FFill
final
hashCode → int
The hash code for this object.
no setterinherited
height → FSize
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nodeState → DSWidgetState
final
paddings → FMargins
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows → FShadow
final
width → FSize
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isParentOfScaffold(DSWidgetState nodeState, PageState state) → bool