UIBoxController class
Properties
-
componentID
→ String
-
Returns the component ID.
no setter
-
componentName
→ String
-
Returns the component name.
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasListeners
→ bool
-
Whether any listeners are currently registered.
no setterinherited
-
rootNode
→ CNode?
-
Returns the first node of the component (the root node).
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
changeTheme(ThemeMode mode)
→ void
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
load()
→ void
-
Loads the component.
It's used to load the component programmatically.
-
nodesToList()
→ List<CNode>
-
Returns the list of nodes of the component.
It's used to render the component.
If the component is not loaded, it returns an empty list.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
onError(ErrorCallback callback)
→ void
-
Returns a callback when the component has an error.
-
onLoaded(LoadedCallback callback)
→ void
-
Returns a callback when the component is loaded.
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited